=====================
1.17.3 (clients only)
=====================

-------
Clients
-------

****
Bugs
****

- Clients: Python 2.6 incompatibility with python logger `#1323 <https://github.com/rucio/rucio/issues/1323>`_
- Clients: common/utils fails when loading dysfunctional paramiko version `#1324 <https://github.com/rucio/rucio/issues/1324>`_
